@@ -1,4 +1,4 @@
-use std::{env, process};
+use std::{collections, env, process};
 use super::*;
 
 #[derive(Debug, Clone)]
@@ -84,7 +84,6 @@ impl ArgParser {
     /// Sets the usage. Replaces all instances of {name} with the program's name.
     pub fn usage(&mut self, s: &str) -> &mut Self {
         self.usage = s.replace("{name}", &self.name);
-        //self.usage = String::from(s);
         self
     }
 
@@ -116,6 +115,34 @@ impl ArgParser {
         }
     }
 
+    /// Returns a copy of the parser's current arguments in HashMap form using the ArgVal struct
+    pub fn map_argval(&self) -> collections::HashMap<String, ArgVal> {
+        let mut out = collections::HashMap::new();
+        for arg in self.args.iter().cloned() {
+            out.insert(arg.name, arg.val);
+        }
+        out
+    }
+
+    /// Returns a copy of the parser's current arguments in HashMap form using tuples
+    pub fn map_tuple(&self) -> collections::HashMap<String, (bool, String)> {
+        let mut out = collections::HashMap::new();
+        for arg in self.args.iter().cloned() {
+            let b = if let ArgVal::Bool(b) = arg.val {
+                b
+            } else {
+                false
+            };
+            let s = if let ArgVal::Str(s) = arg.val {
+                s
+            } else {
+                String::new()
+            };
+            out.insert(arg.name, (b, s));
+        }
+        out
+    }
+
     /// Gets a String value arg by <name>. If no arg is found, default to String::new()
     pub fn get_str(&self, name: &str) -> String {
         for arg in &self.args {
